@@ -804,7 +804,7 @@ class PlainMzMLWriter(ComponentDispatcher, XMLDocumentWriter):
             else:
                 array_type_ = array_type
             if array_type_ not in ARRAY_TYPES:
-                params.append(NON_STANDARD_ARRAY)
+                params.append({"name": NON_STANDARD_ARRAY, "value": array_type_})
         params.append(compression_map[compression])
         params.append(dtype_to_encoding[dtype])
         encoded_length = len(encoded_binary)
